@@ -62,6 +62,12 @@ QNetworkReply* ApiRequestPrivate::suggestionsOpml( uint count )
     return m_requestHandler.authGetRequest( requestUrl );
 }
 
+QNetworkReply* ApiRequestPrivate::downloadSubscriptionsOpml( const QString& username, const QString& device )
+{
+    QString requestUrl = UrlBuilder::getSubscriptionsUrl( username, device, UrlBuilder::OPML );
+    return m_requestHandler.authGetRequest( requestUrl );
+}
+
 QNetworkReply* ApiRequestPrivate::toplistTxt( uint count )
 {
     QString requestUrl = UrlBuilder::getToplistUrl( count, UrlBuilder::TEXT );
@@ -80,6 +86,24 @@ QNetworkReply* ApiRequestPrivate::suggestionsTxt( uint count )
     return m_requestHandler.authGetRequest( requestUrl );
 }
 
+QNetworkReply* ApiRequestPrivate::downloadSubscriptionsTxt(const QString& username, const QString& device)
+{
+    QString requestUrl = UrlBuilder::getSubscriptionsUrl( username, device, UrlBuilder::TEXT );
+    return m_requestHandler.authGetRequest( requestUrl );
+}
+
+QNetworkReply* ApiRequestPrivate::toplistXml ( uint count )
+{
+    QString requestUrl = UrlBuilder::getToplistUrl( count, UrlBuilder::XML );
+    return m_requestHandler.getRequest( requestUrl );
+}
+
+QNetworkReply* ApiRequestPrivate::searchXml( const QString& query )
+{
+    QString requestUrl = UrlBuilder::getPodcastSearchUrl( query, UrlBuilder::XML );
+    return m_requestHandler.getRequest( requestUrl );
+}
+
 PodcastListPtr ApiRequestPrivate::toplist( uint count )
 {
     QString requestUrl = UrlBuilder::getToplistUrl( count );
@@ -108,6 +132,12 @@ PodcastListPtr ApiRequestPrivate::suggestions( uint count )
     return podcastList;
 }
 
+QNetworkReply* ApiRequestPrivate::downloadSubscriptionsJson(const QString& username, const QString& device)
+{
+    QString requestUrl = UrlBuilder::getSubscriptionsUrl( username, device );
+    return m_requestHandler.authGetRequest( requestUrl );
+}
+
 EpisodePtr ApiRequestPrivate::episodeData( const QUrl& podcasturl, const QUrl& episodeurl )
 {
     QString requestUrl = UrlBuilder::getEpisodeDataUrl( podcasturl.toString(), episodeurl.toString() );
@@ -346,12 +376,20 @@ QNetworkReply* ApiRequestPrivate::renameDevice( const QString& username , const
 DeviceListPtr ApiRequestPrivate::listDevices( const QString& username )
 {
     QString requestUrl = UrlBuilder::getDeviceListUrl( username );
-    QNetworkReply *reply;
+    QNetworkReply* reply;
     reply = m_requestHandler.authGetRequest( requestUrl );
     DeviceListPtr list( new DeviceList( reply ) );
     return list;
 }
 
+DeviceSyncResultPtr ApiRequestPrivate::deviceSynchronizationStatus ( const QString& username )
+{
+    QString requestUrl = UrlBuilder::getDeviceSynchronizationStatusUrl( username );
+    QNetworkReply* reply;
+    reply = m_requestHandler.authGetRequest( requestUrl );
+    DeviceSyncResultPtr result( new DeviceSyncResult( reply ) );
+    return result;
+}
 
 ApiRequest::ApiRequest( const QString& username, const QString& password, QNetworkAccessManager* nam ) : d( new ApiRequestPrivate( username, password, nam ) )
 {
@@ -381,6 +419,11 @@ QNetworkReply* ApiRequest::suggestionsOpml( uint count )
     return d->suggestionsOpml( count );
 }
 
+QNetworkReply* ApiRequest::downloadSubscriptionsOpml( const QString& username, const QString& device )
+{
+    return d->downloadSubscriptionsOpml( username, device );
+}
+
 QNetworkReply* ApiRequest::toplistTxt( uint count )
 {
     return d->toplistTxt( count );
@@ -396,6 +439,21 @@ QNetworkReply* ApiRequest::suggestionsTxt( uint count )
     return d->suggestionsTxt( count );
 }
 
+QNetworkReply* ApiRequest::downloadSubscriptionsTxt(const QString& username, const QString& device)
+{
+    return d->downloadSubscriptionsTxt( username, device );
+}
+
+QNetworkReply* ApiRequest::toplistXml ( uint count )
+{
+    return d->toplistXml( count );
+}
+
+QNetworkReply* ApiRequest::searchXml ( const QString& query )
+{
+    return d->searchXml( query );
+}
+
 PodcastListPtr ApiRequest::toplist( uint count )
 {
     return d->toplist( count );
@@ -411,6 +469,11 @@ PodcastListPtr ApiRequest::suggestions( uint count )
     return d->suggestions( count );
 }
 
+QNetworkReply* ApiRequest::downloadSubscriptionsJson(const QString& username, const QString& device)
+{
+    return d->downloadSubscriptionsJson( username, device );
+}
+
 PodcastListPtr ApiRequest::podcastsOfTag( uint count, const QString& tag )
 {
     return d->podcastsOfTag( count, tag );
@@ -493,7 +556,7 @@ EpisodeActionListPtr ApiRequest::episodeActions( const QString& username, const
 
 EpisodeActionListPtr ApiRequest::episodeActionsByPodcast( const QString& username, const QString& podcastUrl, const bool aggregated )
 {
-    return d->episodeActionsByDevice( username, podcastUrl, aggregated );
+    return d->episodeActionsByPodcast( username, podcastUrl, aggregated );
 }
 
 EpisodeActionListPtr ApiRequest::episodeActionsByDevice( const QString& username, const QString& deviceId, const bool aggregated )
@@ -530,3 +593,8 @@ DeviceListPtr ApiRequest::listDevices( const QString& username )
 {
     return d->listDevices( username );
 }
+
+DeviceSyncResultPtr ApiRequest::deviceSynchronizationStatus ( const QString& username )
+{
+    return d->deviceSynchronizationStatus( username );
+}
