@@ -25,7 +25,7 @@
 
 #define MYGPO_MAJOR_VERSION 1
 #define MYGPO_MINOR_VERSION 0
-#define MYGPO_PATCH_VERSION 0
+#define MYGPO_PATCH_VERSION 5
 
 #include "mygpo_export.h"
 #include "AddRemoveResult.h"
@@ -36,6 +36,7 @@
 #include "Settings.h"
 #include "DeviceUpdates.h"
 #include "DeviceList.h"
+#include "DeviceSyncResult.h"
 
 class QByteArray;
 class QString;
@@ -60,7 +61,9 @@ public:
     ApiRequest( QNetworkAccessManager* nam );
     ~ApiRequest( );
     
-	/**
+    //SIMPLE API
+    
+    /**
      * Returns the OPML Result for the Simple API Call "Downloading Podcast Toplists"
      * @param count The number of Podcasts that should be returned - will be set to to 100 if > 100 or < 1
      * @return A Pointer to a QNetworkReply which receives network signals and will contain the data
@@ -84,8 +87,10 @@ public:
      *
      */
     QNetworkReply* suggestionsOpml( uint count );
+    
+    QNetworkReply* downloadSubscriptionsOpml( const QString& username, const QString& device );
 
-	/**
+    /**
      * Returns the TXT Result for the Simple API Call "Downloading Podcast Toplists"
      * @param count The number of Podcasts that should be returned - will be set to to 100 if > 100 or < 1
      * @return A Pointer to a QNetworkReply which receives network signals and will contain the data
@@ -109,7 +114,25 @@ public:
      *
      */
     QNetworkReply* suggestionsTxt( uint count );
-	
+    
+    QNetworkReply* downloadSubscriptionsTxt( const QString& username, const QString& device );
+
+    /**
+     * Returns the TXT Result for the Simple API Call "Downloading Podcast Toplists"
+     * @param count The number of Podcasts that should be returned - will be set to to 100 if > 100 or < 1
+     * @return A Pointer to a QNetworkReply which receives network signals and will contain the data
+     *
+     */
+    QNetworkReply* toplistXml( uint count );
+
+    /**
+     * Returns the XML Result for the Simple API Call "Searching for Podcasts"
+     * @param query The String you want to search for
+     * @return A Pointer to a QNetworkReply which receives network signals and will contain the data
+     *
+     */
+    QNetworkReply* searchXml( const QString& query );
+
     /**
      * Returns the Result for the Simple API Call "Downloading Podcast Toplists"
      * @param count The number of Podcasts that should be returned - will be set to to 100 if > 100 or < 1
@@ -134,6 +157,10 @@ public:
      *
      */
     PodcastListPtr suggestions( uint count );
+    
+    QNetworkReply* downloadSubscriptionsJson( const QString& username, const QString& device );
+    
+    //ADVANCED API
 
     /**
      * Returns the Result for the Advanced API Call "Retrieving Podcasts of a Tag"
@@ -366,7 +393,7 @@ public:
      */
     AddRemoveResultPtr uploadEpisodeActions( const QString& username, const QList<EpisodeActionPtr>& episodeActions );
 
-
+    DeviceSyncResultPtr deviceSynchronizationStatus( const QString& username );
 
 private:
     ApiRequestPrivate* const d;
