@@ -39,7 +39,6 @@ PodcastPrivate::PodcastPrivate( Podcast* qq, const QVariant& variant ): m_reply(
 
 PodcastPrivate::~PodcastPrivate()
 {
-    delete m_reply;
 }
 
 
@@ -208,6 +207,7 @@ void PodcastPrivate::parseData()
     {
         emit q->parseError();
     }
+    m_reply->deleteLater();
 }
 
 void PodcastPrivate::error( QNetworkReply::NetworkError error )
