@@ -34,7 +34,6 @@ SettingsPrivate::SettingsPrivate( Settings* qq, QNetworkReply* reply ): q( qq ),
 
 SettingsPrivate::~SettingsPrivate()
 {
-    delete m_reply;
 }
 
 QVariant SettingsPrivate::settings() const
@@ -74,6 +73,7 @@ void SettingsPrivate::parseData()
             emit q->parseError();
         }
     }
+    m_reply->deleteLater();
 }
 
 
