@@ -47,6 +47,9 @@ static QString getFormatExtension( UrlBuilder::Format f )
     case UrlBuilder::TEXT:
         ret =  QString( QLatin1String( ".txt" ) );
         break;
+    case UrlBuilder::XML:
+        ret = QString( QLatin1String( ".xml" ) );
+        break;
     }
     return ret;
 }
@@ -68,6 +71,11 @@ QString UrlBuilder::getPodcastSearchUrl( const QString& query, Format f )
     return s_server % QLatin1String( "/search" ) % getFormatExtension( f ) % QLatin1String( "?q=" ) % query;
 }
 
+QString UrlBuilder::getSubscriptionsUrl( const QString& username, const QString& device, UrlBuilder::Format f)
+{
+    return s_server % QLatin1String( "/subscriptions/" ) % username % QLatin1String( "/" ) % device % getFormatExtension( f );
+}
+
 QString UrlBuilder::getTopTagsUrl( uint i )
 {
     QString numString = QString::number(( i == 0 ) ? 1 : i );
@@ -192,3 +200,8 @@ QString UrlBuilder::getUploadEpisodeActionsUrl( const QString& username )
 {
     return s_server % s_api2 % QLatin1String( "/episodes/" ) % username % QLatin1String( ".json" );
 }
+
+QString UrlBuilder::getDeviceSynchronizationStatusUrl ( const QString& username )
+{
+    return s_server % s_api2 % QLatin1String( "/sync-devices/" ) % username % QLatin1String( ".json" );
+}
