@@ -43,7 +43,8 @@ public:
     {
         JSON,
         OPML,
-        TEXT
+        TEXT,
+        XML
     };
 
     /**
@@ -64,6 +65,7 @@ public:
      */
     static QString getPodcastSearchUrl( const QString& query, Format f = JSON );
 
+    static QString getSubscriptionsUrl( const QString& username, const QString& device, Format f = JSON );
     /**
      * @param i Amount of tags. If i == 0 it will be set to 1.
      * @return Request URL to retrieve the 'i' most used tags.
@@ -130,6 +132,8 @@ public:
 
     static QString getUploadEpisodeActionsUrl( const QString& username );
 
+    static QString getDeviceSynchronizationStatusUrl( const QString& username );
+
 private:
     UrlBuilder() {};
     UrlBuilder( const UrlBuilder& ) {};
